@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author: Jiajun Ren <jiajunren0522@gmail.com>
+import logging
 import os
 import sys
 import warnings
@@ -17,13 +18,17 @@ if reno_num_threads is not None:
             os.environ[env] = reno_num_threads
             del env
 
-del os, sys, warnings
+del sys, warnings
 
 from renormalizer.utils.log import init_log
 
-init_log()
 
-del init_log
+# logging.DEBUG == 10, logging.INFO == 20. See the logging built-in package for more
+log_level = int(os.environ.get("RENO_LOG_LEVEL", logging.DEBUG))
+
+init_log(log_level)
+
+del os, log_level, init_log
 
 
 # user interfaces
