@@ -3,5 +3,5 @@
 
 from renormalizer.model.phonon import Phonon
 from renormalizer.model.mol import Mol
-from renormalizer.model.op import Op
+from renormalizer.model.op import Op, OpSum
 from renormalizer.model.model import Model, load_from_dict, HolsteinModel, SpinBosonModel, TI1DModel
